==> zen-cart-v1.2.0-l10n-jp-5.zip: zen-cart-v1.2.0-l10n-jp-5/admin/includes/languages/english/music_genre.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2004 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: music_genre.php,v 1.1.1.1 2004/09/01 04:47:09 shidairiki Exp $
//
  define('HEADING_TITLE', 'Music Genres');
  define('TABLE_HEADING_MUSIC_GENRE', 'Music Genres');
  define('TABLE_HEADING_ACTION', 'Action');
  define('TEXT_NEW_INTRO', 'Please enter the details of the new Music Genre below.');
  define('TEXT_EDIT_INTRO', 'Please amend the details of the Music Genre below.');
  define('TEXT_DELETE_INTRO', 'Are you sure you want to delete this Music Genre.');
  define('TEXT_DELETE_IMAGE', 'Delete Image?.');
  define('TEXT_MUSIC_GENRE_NAME', 'Music Genre Name');
  define('TEXT_MUSIC_GENRE_IMAGE', 'Music Genre Image');
  define('TEXT_MUSIC_GENRE_IMAGE_DIR', 'Image Directory&nbsp;');

  define('TEXT_HEADING_NEW_MUSIC_GENRE', 'New Music Genre');
  define('TEXT_HEADING_EDIT_MUSIC_GENRE', 'Edit Music Genre');
  define('TEXT_HEADING_DELETE_MUSIC_GENRE', 'Delete Music Genre');
  define('TEXT_DATE_ADDED', 'Date Added');
  define('TEXT_LAST_MODIFIED', 'Date Modified');
  define('TEXT_IMAGE_NONEXISTENT', 'Image does not exist');
  define('TEXT_PRODUCTS', 'Linked Products');
  define('TEXT_DISPLAY_NUMBER_OF_MUSIC_GENRES', 'Displaying <strong>%d</strong> to <strong>%d</strong> (of <strong>%d</strong> Music Genres)');
?>

==> zen-cart-v1.3.0.2-l10n-jp-5.zip: zen-cart-v1.3.0.2-l10n-jp-5/admin/includes/languages/english/music_genre.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2004 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: music_genre.php 276 2004-09-10 22:35:28Z wilt $
//
  define('HEADING_TITLE', 'Music Genres');
  define('TABLE_HEADING_MUSIC_GENRE', 'Music Genres');
  define('TABLE_HEADING_ACTION', 'Action');
  define('TEXT_NEW_INTRO', 'Please enter the details of the new Music Genre below.');
  define('TEXT_EDIT_INTRO', 'Please amend the details of the Music Genre below.');
  define('TEXT_DELETE_INTRO', 'Are you sure you want to delete this Music Genre.');
  define('TEXT_DELETE_IMAGE', 'Delete Image?.');
  define('TEXT_MUSIC_GENRE_NAME', 'Music Genre Name');
  define('TEXT_MUSIC_GENRE_IMAGE', 'Music Genre Image');
  define('TEXT_MUSIC_GENRE_IMAGE_DIR', 'Image Directory&nbsp;');

  define('TEXT_HEADING_NEW_MUSIC_GENRE', 'New Music Genre');
  define('TEXT_HEADING_EDIT_MUSIC_GENRE', 'Edit Music Genre');
  define('TEXT_HEADING_DELETE_MUSIC_GENRE', 'Delete Music Genre');
  define('TEXT_DATE_ADDED', 'Date Added');
  define('TEXT_LAST_MODIFIED', 'Date Modified');
  define('TEXT_IMAGE_NONEXISTENT', 'Image does not exist');
  define('TEXT_PRODUCTS', 'Linked Products');
  define('TEXT_DISPLAY_NUMBER_OF_MUSIC_GENRES', 'Displaying <strong>%d</strong> to <strong>%d</strong> (of <strong>%d</strong> Music Genres)');
  define('TEXT_DELETE_PRODUCTS', 'Delete this Music Genre and all items linked to it?');
  define('TEXT_DELETE_WARNING_PRODUCTS', '<b>WARNING:</b> There are %s items still linked to this Music Genre!');
?>
